Predictors used in distribution models for waterbird groups during the winter season
Source:R/predictors_waterbird_win.R
predictors_waterbird_win.RdPredictor names and how they crosswalk to the major land cover classes and
subclasses listed in the vegetation key. Land cover classes or subclasses
with NA values in PREDICTOR_NAME and PREDICTOR_NUM are excluded from
these models. This data set is primarily for use in the
reclassify_landcover() function. This crosswalk is nearly identical to
predictors_waterbirds_fall except that in the winter, agricultural fields
specified as "winter wheat" are separated from other grains.
Format
key A data frame with 81 rows and 4 columns:
- CODE_NUM
Numeric value used to encode rasters, matching
key- CODE_NAME
Text string joining major land cover classes to subclasses with a '_', matching
key- PREDICTOR_NAME
Corresponding predictor name in tidal marsh bird distribution models
- PREDICTOR_NUM
Corresponding numeric value used to reclassify land cover rasters for use with tidal marsh bird distribution models